package task

import (
	"context"
	"encoding/json"
	"git.listensoft.net/tool/jspkit/common"
	"git.listensoft.net/tool/jspkit/common/lxhttp"
	"git.listensoft.net/tool/jspkit/common/models"
	"git.listensoft.net/tool/jspkit/common/variable"
	"github.com/go-kratos/kratos/v2/log"
	"github.com/spf13/viper"
	"github.com/tidwall/gjson"
	"os"
	"path/filepath"
	"time"
)

const taxMaxTime = 20 * time.Minute //超时默认20分钟

// GetContent 根据地区定制Content 设置超时时间
func GetContent(childCtx context.Context, address string, pdfTel string, ticker *time.Ticker) (childCtx1 context.Context) {
	if address == "shandong" || address == "neimenggu" || address == "jiangsu" { // 针对20分钟不够用的地区
		childCtx1, _ = context.WithTimeout(childCtx, 30*time.Minute)
	} else if address == "sichuan" || address == "chongqing" || address == "shanxi" || (address == "anhui") {
		childCtx1, _ = context.WithTimeout(childCtx, 40*time.Minute)
	} else if address == "fujian" || address == "beijing" || address == "qinghai" || address == "xiamen" {
		childCtx1, _ = context.WithTimeout(childCtx, 40*time.Minute)
	} else {
		childCtx1, _ = context.WithTimeout(childCtx, taxMaxTime)
	}
	if pdfTel != "" {
		//childCtx1, _ = context.WithTimeout(childCtx, 120*time.Minute) //四川的pdf采集 一个小时不够
		ticker = time.NewTicker(4 * time.Minute) // 每四分钟加五分钟的锁
		go func() {
			for t := range ticker.C { // 阻塞等待接收ticker发出的时间信号
				common.AddTelLockerX2(pdfTel, "300")
				log.Info("Tick at:", t)
			}
		}()
	}
	return
}

// GetTaxTask 获取任务
func GetTaxTask(robotName string) (list []models.TaxTask, err error) {
	client := lxhttp.NewHttpClient()
	defer client.CloseIdleConnections()
	param := map[string]string{
		"robotName": robotName,
	}
	bys, err2 := lxhttp.POSTJson(client, variable.TaxTaskURL+"/api/v1/getRobotQueue", param, map[string]string{})
	if err2 != nil {
		return
	}
	data := gjson.GetBytes(bys, "data").String()
	list = []models.TaxTask{}
	err = json.Unmarshal([]byte(data), &list)
	return
}

// EndQueue 释放机器人
func EndQueue(robotName string) {
	client := lxhttp.NewHttpClient()
	defer client.CloseIdleConnections()
	param := map[string]string{
		"robotName": robotName,
	}
	bys, err2 := lxhttp.POSTJson(client, variable.TaxTaskURL+"/api/v1/endQueue", param, map[string]string{}) // https://task.listensoft.net
	if err2 != nil {
		return
	}
	log.Info("endQueue - ", string(bys))
}

// GetRobotName 获取当前机器人名称
func GetRobotName() string {
	//环境变量中读取名称
	envRobotName := os.Getenv("robotName")
	log.Info("envRobotName:", envRobotName)
	if envRobotName != "" {
		return envRobotName
	}
	//config中读取文件
	confRobotName := viper.GetString("robotName")
	log.Info("confRobotName:", confRobotName)
	if confRobotName != "" { //如果是测试环境 固定一个 robotName 方便调试 一直获取一个任务
		return confRobotName
	}
	//读取不到默认文件夹名称
	dir, _ := os.Getwd()
	_, file := filepath.Split(dir)
	log.Info("fileDIrRobotName:", file)
	return file
}
